@@ -44,7 +44,11 @@ BLOCKCERTS_V3_BETA_CONTEXT = 'https://w3id.org/blockcerts/schema/3.0-beta/contex
 BLOCKCERTS_V3_BETA_SCHEMA = 'https://w3id.org/blockcerts/schema/3.0-beta/schema.json'
 BLOCKCERTS_V3_BETA_CANONICAL_CONTEXT = 'https://w3id.org/blockcerts/v3.0-beta'
 
-BLOCKCERTS_VOCAB = 'https://w3id.org/blockcerts/v3.0-alpha#'
+BLOCKCERTS_V3_CONTEXT = 'https://w3id.org/blockcerts/schema/3.0/context.json'
+BLOCKCERTS_V3_SCHEMA = 'https://w3id.org/blockcerts/schema/3.0/schema.json'
+BLOCKCERTS_V3_CANONICAL_CONTEXT = 'https://w3id.org/blockcerts/v3'
+
+BLOCKCERTS_VOCAB = 'https://w3id.org/blockcerts/3.0#'
 
 JSONLD_OPTIONS = {'algorithm': 'URDNA2015', 'format': 'application/nquads'}
 
@@ -54,6 +58,7 @@ BLOCKCERTS_V2_ALPHA_CONTEXT_2 = 'https://www.blockcerts.org/schema/2.0-alpha/con
 BLOCKCERTS_V2_CONTEXT_2 = 'https://www.blockcerts.org/schema/2.0/context.json'
 BLOCKCERTS_V3_ALPHA_CONTEXT_2 = 'https://www.blockcerts.org/schema/3.0-alpha/context.json'
 BLOCKCERTS_V3_BETA_CONTEXT_2 = 'https://www.blockcerts.org/schema/3.0-beta/context.json'
+BLOCKCERTS_V3_CONTEXT_2 = 'https://www.blockcerts.org/schema/3.0/context.json'
 
 FALLBACK_VOCAB = 'http://fallback.org/'
 FALLBACK_CONTEXT = {'@vocab': FALLBACK_VOCAB}
@@ -78,6 +83,10 @@ CREDENTIAL_JSON_LD_CONTEXT_V1_BETA = os.path.join(BASE_DIR, '3.0-beta/credential
 EXAMPLE_CREDENTIAL_JSON_LD_CONTEXT_V1_BETA = os.path.join(BASE_DIR, '3.0-beta/exampleCredential.json')
 MERKLE_PROOF_2019_JSON_LD_CONTEXT_V1_BETA = os.path.join(BASE_DIR, '3.0-beta/merkleProof2019Context.json')
 
+JSON_LD_CONTEXT_V3_0 = os.path.join(BASE_DIR, '3.0/context.json')
+CREDENTIAL_JSON_LD_CONTEXT_V1 = os.path.join(BASE_DIR, '3.0/credential.json')
+MERKLE_PROOF_2019_JSON_LD_CONTEXT_V1 = os.path.join(BASE_DIR, '3.0/merkleProof2019Context.json')
+
 PRELOADED_CONTEXTS = {}
 
 with open(OBI_JSON_LD_CONTEXT_V2) as data_file:
@@ -138,6 +147,12 @@ with open(JSON_LD_CONTEXT_V3_0_BETA) as data_file:
     PRELOADED_CONTEXTS[BLOCKCERTS_V3_BETA_CONTEXT_2] = bc_context
     PRELOADED_CONTEXTS[BLOCKCERTS_V3_BETA_CANONICAL_CONTEXT] = bc_context
 
+with open(JSON_LD_CONTEXT_V3_0) as data_file:
+    bc_context = json.load(data_file)
+    PRELOADED_CONTEXTS[BLOCKCERTS_V3_CONTEXT] = bc_context
+    PRELOADED_CONTEXTS[BLOCKCERTS_V3_CONTEXT_2] = bc_context
+    PRELOADED_CONTEXTS[BLOCKCERTS_V3_CANONICAL_CONTEXT] = bc_context
+
 
 def to_loader_response(data, url):
     return {
